==> kea-docs-2.0.2-1-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/de/d13/namespaceisc_1_1hooks.js <==
var namespaceisc_1_1hooks =
[
    [ "CalloutHandle", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle.html", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle" ],
    [ "CalloutHandleAssociate", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate.html", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate" ],
    [ "CalloutManager", "d4/d67/classisc_1_1hooks_1_1CalloutManager.html", "d4/d67/classisc_1_1hooks_1_1CalloutManager" ],
    [ "DuplicateHook", "db/de0/classisc_1_1hooks_1_1DuplicateHook.html", "db/de0/classisc_1_1hooks_1_1DuplicateHook" ],
    [ "HooksConfig", "d0/d40/classisc_1_1hooks_1_1HooksConfig.html", "d0/d40/classisc_1_1hooks_1_1HooksConfig" ],
    [ "HooksLibrariesParser", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser.html", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser" ],
    [ "HooksManager", "d4/d88/classisc_1_1hooks_1_1HooksManager.html", null ],
    [ "InvalidHooksLibraries", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries.html", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries" ],
    [ "LibrariesStillOpened", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened.html", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened" ],
    [ "LibraryHandle", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle.html", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle" ],
    [ "LibraryManager", "d4/d98/classisc_1_1hooks_1_1LibraryManager.html", "d4/d98/classisc_1_1hooks_1_1LibraryManager" ],
    [ "LibraryManagerCollection", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection.html", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection" ],
    [ "LoadLibrariesNotCalled", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled" ],
    [ "NoCalloutManager", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager.html", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager" ],
    [ "NoSuchArgument", "db/dee/classisc_1_1hooks_1_1NoSuchArgument.html", "db/dee/classisc_1_1hooks_1_1NoSuchArgument" ],
    [ "NoSuchCalloutContext", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext.html", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext" ],
    [ "NoSuchHook", "d4/d70/classisc_1_1hooks_1_1NoSuchHook.html", "d4/d70/classisc_1_1hooks_1_1NoSuchHook" ],
    [ "NoSuchLibrary", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary.html", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary" ],
    [ "ParkingLot", "dd/db4/classisc_1_1hooks_1_1ParkingLot.html", "dd/db4/classisc_1_1hooks_1_1ParkingLot" ],
    [ "ParkingLotHandle", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle.html", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle" ],
    [ "ParkingLots", "d3/dc8/classisc_1_1hooks_1_1ParkingLots.html", "d3/dc8/classisc_1_1hooks_1_1ParkingLots" ],
    [ "PointerConverter", "da/d42/classisc_1_1hooks_1_1PointerConverter.html", "da/d42/classisc_1_1hooks_1_1PointerConverter" ],
    [ "ScopedCalloutHandleState", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState.html", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState" ],
    [ "ServerHooks", "dc/d4b/classisc_1_1hooks_1_1ServerHooks.html", "dc/d4b/classisc_1_1hooks_1_1ServerHooks" ],
    [ "CalloutHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a8daec5c473b714625a7afe8caaa7b0cb", null ],
    [ "CalloutPtr", "de/d13/namespaceisc_1_1hooks.html#a25e0b3cae1cc1b876313797a010e2af5", null ],
    [ "HookLibInfo", "de/d13/namespaceisc_1_1hooks.html#a001ff7519899ad231220986dd13500fd", null ],
    [ "HookLibsCollection", "de/d13/namespaceisc_1_1hooks.html#a773818c8b5dc3e49ce9705324256a1e1", null ],
    [ "HookLibsCollectionPtr", "de/d13/namespaceisc_1_1hooks.html#a55a63a86b249c1ed2596d6ddadafbc78", null ],
    [ "ParkingLotHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a2363ee6ae0a46a86c9b59a34c199e08b", null ],
    [ "ParkingLotPtr", "de/d13/namespaceisc_1_1hooks.html#af7bee158c4d7a5963cf7a9794bd1d792", null ],
    [ "ParkingLotsPtr", "de/d13/namespaceisc_1_1hooks.html#a20721fe6188da398c74e0881e79c69c3", null ],
    [ "ServerHooksPtr", "de/d13/namespaceisc_1_1hooks.html#a37d12f02f9496f7d4a0f0da7b328541c", null ],
    [ "extractNames", "de/d13/namespaceisc_1_1hooks.html#a1ab505936a27f640b04fc395c8af14d1", null ],
    [ "hooksStaticLinkInit", "de/d13/namespaceisc_1_1hooks.html#a05bf2d7e4b0cd04996efc2bf79ac8f32", null ],
    [ "callouts_logger", "de/d13/namespaceisc_1_1hooks.html#acbbb2087d9d36ce66da865cf425e6c72", null ],
    [ "HOOKS_ALL_CALLOUTS_DEREGISTERED", "de/d13/namespaceisc_1_1hooks.html#ad1890a0f1b706f47493772611ede8cde", null ],
    [ "HOOKS_CALLOUT_CALLED", "de/d13/namespaceisc_1_1hooks.html#af3e33e069a69afd3443d9b9bd9ec7e64", null ],
    [ "HOOKS_CALLOUT_DEREGISTERED", "de/d13/namespaceisc_1_1hooks.html#aec4302f783715c8037786680200e0ea3", null ],
    [ "HOOKS_CALLOUT_ERROR", "de/d13/namespaceisc_1_1hooks.html#ae4d99dfe147439c49ece2f9ada1e1bc8", null ],
    [ "HOOKS_CALLOUT_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a744cf2a92a2e6bdd3919207ccd354ef1", null ],
    [ "HOOKS_CALLOUT_REGISTRATION", "de/d13/namespaceisc_1_1hooks.html#a7aa773bc819485aedb931462f45777b6", null ],
    [ "HOOKS_CALLOUTS_BEGIN", "de/d13/namespaceisc_1_1hooks.html#a7754165c8e0516d15ef92e29b6ef218a", null ],
    [ "HOOKS_CALLOUTS_COMPLETE", "de/d13/namespaceisc_1_1hooks.html#a5add6dae8afb1343a71c08a1dc9f0ca1", null ],
    [ "HOOKS_CALLOUTS_REMOVED", "de/d13/namespaceisc_1_1hooks.html#af2ec31db00263f22d9f1287fd2afbedc", null ],
    [ "HOOKS_CLOSE_ERROR", "de/d13/namespaceisc_1_1hooks.html#af05d66ee6ee0f739cd81662ccd3fe5ab", null ],
    [ "HOOKS_DBG_CALLS", "de/d13/namespaceisc_1_1hooks.html#aaa77c5c31926f41257d889e8db802bc2", null ],
    [ "HOOKS_DBG_EXTENDED_CALLS", "de/d13/namespaceisc_1_1hooks.html#a2f8600b642c8eb467c5bd94ea9760f33", null ],
    [ "HOOKS_DBG_TRACE", "de/d13/namespaceisc_1_1hooks.html#aba65face2cfe789f3b2aacb225e39aa2", null ],
    [ "HOOKS_HOOK_LIST_RESET", "de/d13/namespaceisc_1_1hooks.html#a2b29fc8ab15c9d60dceb2056faab9da8", null ],
    [ "HOOKS_INCORRECT_VERSION", "de/d13/namespaceisc_1_1hooks.html#a8a3fce5afa875be3c0f70d0706df37fd", null ],
    [ "HOOKS_LIBRARY_CLOSED", "de/d13/namespaceisc_1_1hooks.html#ac17ac4ea8e0385fa128f985b49c043f8", null ],
    [ "HOOKS_LIBRARY_LOADED", "de/d13/namespaceisc_1_1hooks.html#a82e442f33b830a77b4bbee9df83d7920", null ],
    [ "HOOKS_LIBRARY_LOADING", "de/d13/namespaceisc_1_1hooks.html#a8a51e05d2011ad9cb3f8660a6687dc47", null ],
    [ "HOOKS_LIBRARY_MULTI_THREADING_COMPATIBLE", "de/d13/namespaceisc_1_1hooks.html#a235b9bd905e5804fe01804792002e894", null ],
    [ "HOOKS_LIBRARY_MULTI_THREADING_NOT_COMPATIBLE", "de/d13/namespaceisc_1_1hooks.html#a2f39f6fb2c47e83a0ebc88c6ecc1c260", null ],
    [ "HOOKS_LIBRARY_UNLOADED", "de/d13/namespaceisc_1_1hooks.html#a11e9b58c742e9a05ef45a56e3877da6e", null ],
    [ "HOOKS_LIBRARY_UNLOADING", "de/d13/namespaceisc_1_1hooks.html#a7e94ff7c3e6aaf107f4496b73e1173c3", null ],
    [ "HOOKS_LIBRARY_VERSION", "de/d13/namespaceisc_1_1hooks.html#a4ab3e1924c3b2881db6f6be20cd4f414", null ],
    [ "HOOKS_LOAD_ERROR", "de/d13/namespaceisc_1_1hooks.html#ab6a95b7797d9deb0e029bb9bf1998477", null ],
    [ "HOOKS_LOAD_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#acb98bfbedee2e833bec0c049a5d27150", null ],
    [ "HOOKS_LOAD_FRAMEWORK_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a311cb273547aae4ebd72e1a7554a42fd", null ],
    [ "HOOKS_LOAD_SUCCESS", "de/d13/namespaceisc_1_1hooks.html#ae9353eafde946ac3bb08f1066b7c395f", null ],
    [ "hooks_logger", "de/d13/namespaceisc_1_1hooks.html#a71f7ced36e8ea37b60cc7cb16eb9bc9f", null ],
    [ "HOOKS_MULTI_THREADING_COMPATIBLE_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#af45a76e5ae3f7db0aa1e5bcede408bc1", null ],
    [ "HOOKS_NO_LOAD", "de/d13/namespaceisc_1_1hooks.html#af219b3bf5b084e2ceb47f08a7e4367c6", null ],
    [ "HOOKS_NO_UNLOAD", "de/d13/namespaceisc_1_1hooks.html#a590cd3f7271f803b601c561e5d4b3f32", null ],
    [ "HOOKS_NO_VERSION", "de/d13/namespaceisc_1_1hooks.html#af0a3cf1010c848a6d3e67cb17f91dd37", null ],
    [ "HOOKS_OPEN_ERROR", "de/d13/namespaceisc_1_1hooks.html#ad480159e342668ab8c5285c105545073", null ],
    [ "HOOKS_STD_CALLOUT_REGISTERED", "de/d13/namespaceisc_1_1hooks.html#a70e07049e9ed7fe25d6f49feae21084f", null ],
    [ "HOOKS_UNLOAD_ERROR", "de/d13/namespaceisc_1_1hooks.html#ae6447127eeeb21eadd20765ef605e583", null ],
    [ "HOOKS_UNLOAD_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#aa7b690f3eda714693f074700430a0a7a", null ],
    [ "HOOKS_UNLOAD_FRAMEWORK_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#ad814f8c8a681f0c7342d55a6181d88e0", null ],
    [ "HOOKS_UNLOAD_SUCCESS", "de/d13/namespaceisc_1_1hooks.html#a3fa693a52bb13f2a402fb680e457d720", null ],
    [ "HOOKS_VERSION_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a5bbd58625c03ef8f4aaf67a5812bfd6a", null ]
];

==> kea-docs-3.1.0-1-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/de/d13/namespaceisc_1_1hooks.js <==
var namespaceisc_1_1hooks =
[
    [ "CalloutHandle", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle.html", "d7/d9b/classisc_1_1hooks_1_1CalloutHandle" ],
    [ "CalloutHandleAssociate", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate.html", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate" ],
    [ "CalloutManager", "d4/d67/classisc_1_1hooks_1_1CalloutManager.html", "d4/d67/classisc_1_1hooks_1_1CalloutManager" ],
    [ "DuplicateHook", "db/de0/classisc_1_1hooks_1_1DuplicateHook.html", "db/de0/classisc_1_1hooks_1_1DuplicateHook" ],
    [ "HookLibInfo", "d0/daa/structisc_1_1hooks_1_1HookLibInfo.html", "d0/daa/structisc_1_1hooks_1_1HookLibInfo" ],
    [ "HookLibraryScriptsChecker", "d8/d87/classisc_1_1hooks_1_1HookLibraryScriptsChecker.html", null ],
    [ "HooksConfig", "d0/d40/classisc_1_1hooks_1_1HooksConfig.html", "d0/d40/classisc_1_1hooks_1_1HooksConfig" ],
    [ "HooksLibrariesParser", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser.html", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser" ],
    [ "HooksManager", "d4/d88/classisc_1_1hooks_1_1HooksManager.html", null ],
    [ "InvalidHooksLibraries", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries.html", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries" ],
    [ "LibrariesStillOpened", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened.html", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened" ],
    [ "LibraryHandle", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle.html", "d2/d6c/classisc_1_1hooks_1_1LibraryHandle" ],
    [ "LibraryManager", "d4/d98/classisc_1_1hooks_1_1LibraryManager.html", "d4/d98/classisc_1_1hooks_1_1LibraryManager" ],
    [ "LibraryManagerCollection", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection.html", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection" ],
    [ "LoadLibrariesNotCalled", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled" ],
    [ "NoCalloutManager", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager.html", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager" ],
    [ "NoSuchArgument", "db/dee/classisc_1_1hooks_1_1NoSuchArgument.html", "db/dee/classisc_1_1hooks_1_1NoSuchArgument" ],
    [ "NoSuchCalloutContext", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext.html", "d3/dbd/classisc_1_1hooks_1_1NoSuchCalloutContext" ],
    [ "NoSuchHook", "d4/d70/classisc_1_1hooks_1_1NoSuchHook.html", "d4/d70/classisc_1_1hooks_1_1NoSuchHook" ],
    [ "NoSuchLibrary", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary.html", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary" ],
    [ "ParkingLot", "dd/db4/classisc_1_1hooks_1_1ParkingLot.html", "dd/db4/classisc_1_1hooks_1_1ParkingLot" ],
    [ "ParkingLotHandle", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle.html", "d4/d2c/classisc_1_1hooks_1_1ParkingLotHandle" ],
    [ "ParkingLots", "d3/dc8/classisc_1_1hooks_1_1ParkingLots.html", "d3/dc8/classisc_1_1hooks_1_1ParkingLots" ],
    [ "PointerConverter", "da/d42/classisc_1_1hooks_1_1PointerConverter.html", "da/d42/classisc_1_1hooks_1_1PointerConverter" ],
    [ "ScopedCalloutHandleState", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState.html", "da/d87/classisc_1_1hooks_1_1ScopedCalloutHandleState" ],
    [ "ServerHooks", "dc/d4b/classisc_1_1hooks_1_1ServerHooks.html", "dc/d4b/classisc_1_1hooks_1_1ServerHooks" ],
    [ "CalloutHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a8daec5c473b714625a7afe8caaa7b0cb", null ],
    [ "CalloutPtr", "de/d13/namespaceisc_1_1hooks.html#a25e0b3cae1cc1b876313797a010e2af5", null ],
    [ "HookLibsCollection", "de/d13/namespaceisc_1_1hooks.html#a773818c8b5dc3e49ce9705324256a1e1", null ],
    [ "HookLibsCollectionPtr", "de/d13/namespaceisc_1_1hooks.html#a55a63a86b249c1ed2596d6ddadafbc78", null ],
    [ "ParkingLotHandlePtr", "de/d13/namespaceisc_1_1hooks.html#a2363ee6ae0a46a86c9b59a34c199e08b", null ],
    [ "ParkingLotPtr", "de/d13/namespaceisc_1_1hooks.html#af7bee158c4d7a5963cf7a9794bd1d792", null ],
    [ "ParkingLotsPtr", "de/d13/namespaceisc_1_1hooks.html#a20721fe6188da398c74e0881e79c69c3", null ],
    [ "ServerHooksPtr", "de/d13/namespaceisc_1_1hooks.html#a37d12f02f9496f7d4a0f0da7b328541c", null ],
    [ "extractNames", "de/d13/namespaceisc_1_1hooks.html#a1ab505936a27f640b04fc395c8af14d1", null ],
    [ "hooksStaticLinkInit", "de/d13/namespaceisc_1_1hooks.html#a05bf2d7e4b0cd04996efc2bf79ac8f32", null ],
    [ "callouts_logger", "de/d13/namespaceisc_1_1hooks.html#acbbb2087d9d36ce66da865cf425e6c72", null ],
    [ "HOOKS_ALL_CALLOUTS_DEREGISTERED", "de/d13/namespaceisc_1_1hooks.html#ad1890a0f1b706f47493772611ede8cde", null ],
    [ "HOOKS_CALLOUT_CALLED", "de/d13/namespaceisc_1_1hooks.html#af3e33e069a69afd3443d9b9bd9ec7e64", null ],
    [ "HOOKS_CALLOUT_DEREGISTERED", "de/d13/namespaceisc_1_1hooks.html#aec4302f783715c8037786680200e0ea3", null ],
    [ "HOOKS_CALLOUT_ERROR", "de/d13/namespaceisc_1_1hooks.html#ae4d99dfe147439c49ece2f9ada1e1bc8", null ],
    [ "HOOKS_CALLOUT_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a744cf2a92a2e6bdd3919207ccd354ef1", null ],
    [ "HOOKS_CALLOUT_REGISTRATION", "de/d13/namespaceisc_1_1hooks.html#a7aa773bc819485aedb931462f45777b6", null ],
    [ "HOOKS_CALLOUTS_BEGIN", "de/d13/namespaceisc_1_1hooks.html#a7754165c8e0516d15ef92e29b6ef218a", null ],
    [ "HOOKS_CALLOUTS_COMPLETE", "de/d13/namespaceisc_1_1hooks.html#a5add6dae8afb1343a71c08a1dc9f0ca1", null ],
    [ "HOOKS_CALLOUTS_REMOVED", "de/d13/namespaceisc_1_1hooks.html#af2ec31db00263f22d9f1287fd2afbedc", null ],
    [ "HOOKS_CLOSE_ERROR", "de/d13/namespaceisc_1_1hooks.html#af05d66ee6ee0f739cd81662ccd3fe5ab", null ],
    [ "HOOKS_DBG_CALLS", "de/d13/namespaceisc_1_1hooks.html#aaa77c5c31926f41257d889e8db802bc2", null ],
    [ "HOOKS_DBG_EXTENDED_CALLS", "de/d13/namespaceisc_1_1hooks.html#a2f8600b642c8eb467c5bd94ea9760f33", null ],
    [ "HOOKS_DBG_TRACE", "de/d13/namespaceisc_1_1hooks.html#aba65face2cfe789f3b2aacb225e39aa2", null ],
    [ "HOOKS_HOOK_LIST_RESET", "de/d13/namespaceisc_1_1hooks.html#a2b29fc8ab15c9d60dceb2056faab9da8", null ],
    [ "HOOKS_INCORRECT_VERSION", "de/d13/namespaceisc_1_1hooks.html#a8a3fce5afa875be3c0f70d0706df37fd", null ],
    [ "HOOKS_LIBPATH_SECURITY_WARNING", "de/d13/namespaceisc_1_1hooks.html#a35d986d109af45730e4d7d4a91addf2a", null ],
    [ "HOOKS_LIBRARY_CLOSED", "de/d13/namespaceisc_1_1hooks.html#ac17ac4ea8e0385fa128f985b49c043f8", null ],
    [ "HOOKS_LIBRARY_LOADED", "de/d13/namespaceisc_1_1hooks.html#a82e442f33b830a77b4bbee9df83d7920", null ],
    [ "HOOKS_LIBRARY_LOADING", "de/d13/namespaceisc_1_1hooks.html#a8a51e05d2011ad9cb3f8660a6687dc47", null ],
    [ "HOOKS_LIBRARY_MULTI_THREADING_COMPATIBLE", "de/d13/namespaceisc_1_1hooks.html#a235b9bd905e5804fe01804792002e894", null ],
    [ "HOOKS_LIBRARY_MULTI_THREADING_NOT_COMPATIBLE", "de/d13/namespaceisc_1_1hooks.html#a2f39f6fb2c47e83a0ebc88c6ecc1c260", null ],
    [ "HOOKS_LIBRARY_UNLOADED", "de/d13/namespaceisc_1_1hooks.html#a11e9b58c742e9a05ef45a56e3877da6e", null ],
    [ "HOOKS_LIBRARY_UNLOADING", "de/d13/namespaceisc_1_1hooks.html#a7e94ff7c3e6aaf107f4496b73e1173c3", null ],
    [ "HOOKS_LIBRARY_VERSION", "de/d13/namespaceisc_1_1hooks.html#a4ab3e1924c3b2881db6f6be20cd4f414", null ],
    [ "HOOKS_LOAD_ERROR", "de/d13/namespaceisc_1_1hooks.html#ab6a95b7797d9deb0e029bb9bf1998477", null ],
    [ "HOOKS_LOAD_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#acb98bfbedee2e833bec0c049a5d27150", null ],
    [ "HOOKS_LOAD_FRAMEWORK_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a311cb273547aae4ebd72e1a7554a42fd", null ],
    [ "HOOKS_LOAD_SUCCESS", "de/d13/namespaceisc_1_1hooks.html#ae9353eafde946ac3bb08f1066b7c395f", null ],
    [ "hooks_logger", "de/d13/namespaceisc_1_1hooks.html#a71f7ced36e8ea37b60cc7cb16eb9bc9f", null ],
    [ "HOOKS_MULTI_THREADING_COMPATIBLE_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#af45a76e5ae3f7db0aa1e5bcede408bc1", null ],
    [ "HOOKS_NO_LOAD", "de/d13/namespaceisc_1_1hooks.html#af219b3bf5b084e2ceb47f08a7e4367c6", null ],
    [ "HOOKS_NO_UNLOAD", "de/d13/namespaceisc_1_1hooks.html#a590cd3f7271f803b601c561e5d4b3f32", null ],
    [ "HOOKS_NO_VERSION", "de/d13/namespaceisc_1_1hooks.html#af0a3cf1010c848a6d3e67cb17f91dd37", null ],
    [ "HOOKS_OPEN_ERROR", "de/d13/namespaceisc_1_1hooks.html#ad480159e342668ab8c5285c105545073", null ],
    [ "HOOKS_STD_CALLOUT_REGISTERED", "de/d13/namespaceisc_1_1hooks.html#a70e07049e9ed7fe25d6f49feae21084f", null ],
    [ "HOOKS_UNLOAD_ERROR", "de/d13/namespaceisc_1_1hooks.html#ae6447127eeeb21eadd20765ef605e583", null ],
    [ "HOOKS_UNLOAD_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#aa7b690f3eda714693f074700430a0a7a", null ],
    [ "HOOKS_UNLOAD_FRAMEWORK_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#ad814f8c8a681f0c7342d55a6181d88e0", null ],
    [ "HOOKS_UNLOAD_SUCCESS", "de/d13/namespaceisc_1_1hooks.html#a3fa693a52bb13f2a402fb680e457d720", null ],
    [ "HOOKS_VERSION_EXCEPTION", "de/d13/namespaceisc_1_1hooks.html#a5bbd58625c03ef8f4aaf67a5812bfd6a", null ]
];
